@@ -79,7 +79,7 @@ class TreeConfigParser:
         """
         key = keylist[0]
         if len(keylist) > 1:
-            if update_tree and not key in self.tree:
+            if update_tree and key not in self.tree:
                 self.tree[key] = TreeConfigParser()
             self.tree[key].set(keylist[1:], value, update_tree)
         else:
@@ -208,7 +208,7 @@ class TreeConfigParser:
         """
         if keylist:
             key = keylist[0]
-            if update_tree and not key in self.tree:
+            if update_tree and key not in self.tree:
                 self.tree[key] = TreeConfigParser()
             self.tree[key].merge(config, keylist[1:], update_tree)
         else:
@@ -569,7 +569,7 @@ def string_conversion(value, to_type='string', **kwargs):
     **String to string**: no conversion is performed, directly returns
     *value*.
 
-    **String to path**: converts the value to a `pathlib.Path` instance.
+    **String to path**: converts the value to a `path.Path` instance.
 
     **String to bool**: converts the value to a boolean.
 
